# python-mod

![](https://travis-ci.com/Future-Walkers/python-mod.svg?branch=master)

Useful modules for python

## Installation

```shell script
pip install -U wisbec
```

## Upload to pypi

1. Modify `ChangeLog`
2. add required modules to `requirements.txt`
3. run `pypi_upload.sh`